pub struct Bytes<'a> { /* fields omitted */ }
A slice wrapper that implements BytesRead.
You should probably use:
let bytes: Bytes = slice.into();
let bytes = Bytes::from(slice);
Returns the inner slice with the original reference.
Returns the entire slice.
Returns all remaining bytes.
Tries to read a given length without updating
the internal position. Returns None if there are not enought
bytes remaining. Read more
Returns the length of the entire slice.
Reads
1
bytes converting them into an u8. Read more
Reads
2
bytes converting them into an u16. Read more
Reads
4
bytes converting them into an u32. Read more
Reads
8
bytes converting them into an u64. Read more
Reads
16
bytes converting them into an u128. Read more
Reads
1
bytes converting them into an i8. Read more
Reads
2
bytes converting them into an i16. Read more
Reads
4
bytes converting them into an i32. Read more
Reads
8
bytes converting them into an i64. Read more
Reads
16
bytes converting them into an i128. Read more
Reads
4
bytes converting them into an f32. Read more
Reads
8
bytes converting them into an f64. Read more
Returns the internal position.
Sets the internal position.
If the position exceeds the slice.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.